package org.jfree.report.demo.groups;

import java.util.ArrayList;
import javax.swing.table.AbstractTableModel;

public class LogEventTableModel extends AbstractTableModel
{
  private static final String[] COLNAMES = new String[]{
          "timestamp", "event", "description"
  };

  private ArrayList events;

  public LogEventTableModel ()
  {
    events = new ArrayList();
  }

  public void addEvent (LogEvent event)
  {
    events.add(event);
  }
  /**
   * Returns a default name for the column using spreadsheet conventions: A, B, C, ... Z,
   * AA, AB, etc.  If <code>column</code> cannot be found, returns an empty string.
   *
   * @param column the column being queried
   * @return a string containing the default name of <code>column</code>
   */
  public String getColumnName (int column)
  {
    return COLNAMES[column];
  }

  /**
   * Returns the number of columns in the model. A <code>JTable</code> uses this method to
   * determine how many columns it should create and display by default.
   *
   * @return the number of columns in the model
   *
   * @see #getRowCount
   */
  public int getColumnCount ()
  {
    return COLNAMES.length;
  }

  /**
   * Returns the number of rows in the model. A <code>JTable</code> uses this method to
   * determine how many rows it should display.  This method should be quick, as it is
   * called frequently during rendering.
   *
   * @return the number of rows in the model
   *
   * @see #getColumnCount
   */
  public int getRowCount ()
  {
    return events.size();
  }

  /**
   * Returns the value for the cell at <code>columnIndex</code> and
   * <code>rowIndex</code>.
   *
   * @param  rowIndex  the row whose value is to be queried
   * @param  columnIndex the column whose value is to be queried
   * @return the value Object at the specified cell
   */
  public Object getValueAt (int rowIndex, int columnIndex)
  {
    // todo implement me
    LogEvent event = (LogEvent) events.get(rowIndex);
    switch(columnIndex)
    {
      case 0: return event.getTimestamp();
      case 1: return event.getEvent();
      case 2: return event.getDescription();
    }
    return null;
  }
}
