/**
 * ========================================
 * JFreeReport : a free Java report library
 * ========================================
 *
 * Project Info:  http://www.jfree.org/jfreereport/index.html
 * Project Lead:  Thomas Morgner;
 *
 * (C) Copyright 2000-2003, by Object Refinery Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * ------------------------------
 * RectangleTemplate.java
 * ------------------------------
 * (C)opyright 2003, by Thomas Morgner and Contributors.
 *
 * Original Author:  Thomas Morgner;
 * Contributor(s):   David Gilbert (for Object Refinery Limited);
 *
 * $Id: RoundRectangleTemplate.java,v 1.1.2.1 2006/02/27 17:57:01 taqua Exp $
 *
 * Changes
 * -------------------------
 * 12-Jul-2003 : Initial version
 *
 */

package org.jfree.report.filter.templates;

import java.awt.geom.RoundRectangle2D;

/**
 * A template to create rectangle elements. The rectangle always has the width and the
 * height of 100 points.
 * <p/>
 * This implementation is used to cover the common use of the rectangle shape element. Use
 * the scaling feature of the shape element to adjust the size of the rectangle.
 *
 * @author Thomas Morgner
 */
public class RoundRectangleTemplate extends AbstractTemplate
{
  private float arcWidth;
  private float arcHeight;

  /**
   * Default Constructor.
   */
  public RoundRectangleTemplate ()
  {
  }

  public float getArcWidth()
  {
    return arcWidth;
  }

  public void setArcWidth(final float arcWidth)
  {
    this.arcWidth = arcWidth;
  }

  public float getArcHeight()
  {
    return arcHeight;
  }

  public void setArcHeight(final float arcHeight)
  {
    this.arcHeight = arcHeight;
  }

  /**
   * Returns the template value, a Rectangle2D.
   *
   * @return a rectangle with a width and height of 100.
   */
  public Object getValue ()
  {
    return new RoundRectangle2D.Float(0, 0, 100, 100, arcWidth, arcHeight);
  }
}
