/**
 * ========================================
 * JFreeReport : a free Java report library
 * ========================================
 *
 * Project Info:  http://www.jfree.org/jfreereport/index.html
 * Project Lead:  Thomas Morgner;
 *
 * (C) Copyright 2000-2005, by Object Refinery Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 *
 * ------------
 * ExpressionPropertyReadHandler.java
 * ------------
 * (C) Copyright 2002-2005, by Object Refinery Limited.
 *
 * Original Author:  Thomas Morgner;
 * Contributor(s):   -;
 *
 * $Id: ExpressionPropertyReadHandler.java,v 1.6 2006/02/10 14:58:45 taqua Exp $
 *
 * Changes
 * -------
 *
 *
 */
package org.jfree.report.modules.parser.base.common;

import org.jfree.report.modules.parser.base.CommentHintPath;
import org.jfree.report.modules.parser.base.PropertyAttributes;
import org.jfree.report.modules.parser.base.PropertyStringReadHandler;
import org.jfree.report.util.CharacterEntityParser;
import org.jfree.report.util.beans.BeanException;
import org.jfree.report.util.beans.BeanUtility;
import org.jfree.util.ObjectUtilities;
import org.jfree.xml.ElementDefinitionException;
import org.jfree.xml.ParseException;
import org.jfree.xml.parser.XmlReaderException;
import org.xml.sax.SAXException;

public class ExpressionPropertyReadHandler extends PropertyStringReadHandler
{
  public static final String NAME_ATT = "name";
  public static final String CLASS_ATT = "class";

  private BeanUtility beanUtility;
  private CharacterEntityParser entityParser;
  private String propertyName;
  private String propertyType;
  private String expressionName;

  public ExpressionPropertyReadHandler (final BeanUtility expression,
                                        final String expressionName,
                                        final CharacterEntityParser entityParser,
                                        final CommentHintPath expressionHintPath)
  {
    super(expressionHintPath);
    this.expressionName = expressionName;
    this.beanUtility = expression;
    this.entityParser = entityParser;
  }


  /**
   * Starts parsing.
   *
   * @param attrs the attributes.
   * @throws org.xml.sax.SAXException if there is a parsing error.
   */
  protected void startParsing (final PropertyAttributes attrs)
          throws SAXException, XmlReaderException
  {
    super.startParsing(attrs);
    propertyType = attrs.getValue(CLASS_ATT);
    propertyName = attrs.getValue(NAME_ATT);
    if (propertyName == null)
    {
      throw new ElementDefinitionException("Required attribute 'name' is null.");
    }
    getHintPath().addName(propertyName);
  }

  /**
   * Done parsing.
   *
   * @throws org.xml.sax.SAXException if there is a parsing error.
   * @throws org.jfree.xml.parser.XmlReaderException
   *                                  if there is a reader error.
   */
  protected void doneParsing ()
          throws SAXException, XmlReaderException
  {
    super.doneParsing();
    final String result = getResult();
    if (beanUtility == null)
    {
      throw new ParseException("No current beanUtility");
    }
    try
    {
      if (propertyType != null)
      {
        ClassLoader cl = ObjectUtilities.getClassLoader
                (ExpressionPropertyReadHandler.class);
        Class c = cl.loadClass(propertyType);
        beanUtility.setPropertyAsString
              (propertyName, c, entityParser.decodeEntities(result));
      }
      else
      {
        beanUtility.setPropertyAsString
              (propertyName, entityParser.decodeEntities(result));
      }
    }
    catch (BeanException e)
    {
      throw new ParseException("Unable to assign property '" + propertyName
              + "' to expression '" + expressionName + "'", e);
    }
    catch (ClassNotFoundException e)
    {
      throw new ParseException("Unable to assign property '" + propertyName
              + "' to expression '" + expressionName + "'", e);
    }
  }

  /**
   * Returns the object for this element or null, if this element does not create an
   * object.
   *
   * @return the object.
   */
  public Object getObject ()
  {
    return null;
  }

}
