/**
 * ========================================
 * JFreeReport : a free Java report library
 * ========================================
 *
 * Project Info:  http://www.jfree.org/jfreereport/index.html
 * Project Lead:  Thomas Morgner;
 *
 * (C) Copyright 2000-2005, by Object Refinery Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 *
 * ------------
 * BasicObjectReadHandler.java
 * ------------
 * (C) Copyright 2002-2005, by Object Refinery Limited.
 *
 * Original Author:  Thomas Morgner;
 * Contributor(s):   -;
 *
 * $Id: BasicObjectReadHandler.java,v 1.7 2005/09/07 14:25:11 taqua Exp $
 *
 * Changes
 * -------
 *
 *
 */
package org.jfree.report.modules.parser.ext.readhandlers;

import org.jfree.report.modules.parser.base.AbstractPropertyXmlReadHandler;
import org.jfree.report.modules.parser.base.CommentHintPath;
import org.jfree.report.modules.parser.base.PropertyAttributes;
import org.jfree.util.ObjectUtilities;
import org.jfree.xml.ElementDefinitionException;
import org.jfree.xml.factory.objects.ClassFactory;
import org.jfree.xml.factory.objects.ObjectDescription;
import org.jfree.xml.parser.RootXmlReadHandler;
import org.jfree.xml.parser.XmlReaderException;
import org.jfree.xml.parser.coretypes.StringReadHandler;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

public class BasicObjectReadHandler extends AbstractPropertyXmlReadHandler
{
  private ObjectDescription objectDescription;
  private StringReadHandler stringReadHandler;
  private ClassFactory classFactory;
  private CommentHintPath commentHintPath;

  /**
   * @param objectDescription may be null.
   * @param commentHintPath   never null.
   */
  public BasicObjectReadHandler (final ObjectDescription objectDescription,
                                 final CommentHintPath commentHintPath)
  {
    this.stringReadHandler = new StringReadHandler();
    if (commentHintPath == null)
    {
      throw new NullPointerException("CommentHintPath must not be null.");
    }
    this.objectDescription = objectDescription;
    this.commentHintPath = commentHintPath;
  }

  /**
   * Initialises the handler.
   *
   * @param rootHandler the root handler.
   * @param tagName     the tag name.
   */
  public void init (final RootXmlReadHandler rootHandler, final String tagName)
  {
    super.init(rootHandler, tagName);
    this.classFactory = (ClassFactory)
            getRootHandler().getHelperObject(ReportDefinitionReadHandler.CLASS_FACTORY_KEY);
  }

  protected ObjectDescription getObjectDescription ()
  {
    return objectDescription;
  }

  protected void setObjectDescription (final ObjectDescription objectDescription)
  {
    this.objectDescription = objectDescription;
  }

  protected ClassFactory getClassFactory ()
  {
    return classFactory;
  }

  /**
   * Starts parsing.
   *
   * @param attrs the attributes.
   * @throws org.xml.sax.SAXException if there is a parsing error.
   */
  protected void startParsing (final PropertyAttributes attrs)
          throws SAXException, XmlReaderException
  {
    handleStartParsing(attrs);
    getRootHandler().delegate(stringReadHandler, getTagName(), attrs);
  }

  protected void handleStartParsing (final Attributes attrs)
          throws ElementDefinitionException
  {
    final String name = attrs.getValue("name");
    if (name == null)
    {
      throw new ElementDefinitionException
              ("Required attribute 'name' is missing.", getRootHandler().getLocator());
    }


    final String attrClass = attrs.getValue("class");
    if (attrClass != null)
    {
      try
      {
        final ClassLoader loader = ObjectUtilities.getClassLoader(BasicObjectReadHandler.class);
        final Class clazz = loader.loadClass(attrClass);
        objectDescription = ObjectFactoryUtility.findDescription(classFactory, clazz);
      }
      catch (ClassNotFoundException e)
      {
        throw new ElementDefinitionException
                ("Value for given 'class' attribute is invalid",
                        getRootHandler().getLocator());
      }
    }
  }

  /**
   * Done parsing.
   *
   * @throws org.xml.sax.SAXException if there is a parsing error.
   * @throws org.jfree.xml.parser.XmlReaderException
   *                                  if there is a reader error.
   */
  protected void doneParsing ()
          throws SAXException, XmlReaderException
  {
    final String value = stringReadHandler.getResult();
    objectDescription.setParameter("value", value);
    super.doneParsing();
  }

  protected CommentHintPath getCommentHintPath ()
  {
    return commentHintPath;
  }

  /**
   * Returns the object for this element or null, if this element does not create an
   * object.
   *
   * @return the object.
   *
   * @throws org.jfree.xml.parser.XmlReaderException
   *          if there is a parsing error.
   */
  public Object getObject ()
          throws XmlReaderException
  {
    objectDescription.configure(getRootHandler());
    return objectDescription.createObject();
  }

  protected void storeComments ()
          throws SAXException
  {
    defaultStoreComments(commentHintPath);
  }
}
