/**
 * ========================================
 * <libname> : a free Java <foobar> library
 * ========================================
 *
 * Project Info:  http://www.jfree.org/liblayout/
 * Project Lead:  Thomas Morgner;
 *
 * (C) Copyright 2005, by Object Refinery Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * ---------
 * DataFactoryReadHandler.java
 * ---------
 *
 * Original Author:  Thomas Morgner;
 * Contributors: -;
 *
 * $Id: DataFactoryReadHandler.java,v 1.1.2.1 2006/06/27 10:39:21 taqua Exp $
 *
 * Changes
 * -------------------------
 * 27.06.2006 : Initial version
 */
package org.jfree.report.modules.parser.ext.readhandlers;

import org.jfree.report.modules.parser.base.AbstractPropertyXmlReadHandler;
import org.jfree.report.modules.parser.base.CommentHintPath;
import org.jfree.report.modules.parser.base.PropertyAttributes;
import org.jfree.report.DataFactory;
import org.jfree.report.JFreeReport;
import org.jfree.xml.parser.XmlReaderException;
import org.jfree.util.ObjectUtilities;
import org.xml.sax.SAXException;

/**
 * Creation-Date: 27.06.2006, 12:09:08
 *
 * @author Thomas Morgner
 */
public class DataFactoryReadHandler extends AbstractPropertyXmlReadHandler
{
  public DataFactoryReadHandler()
  {
  }

  protected void storeComments() throws SAXException
  {
    final CommentHintPath path = new CommentHintPath("report-definition");
    path.addName("report-config");
    path.addName("datafactory");
    defaultStoreComments(path);
  }

  protected void startParsing(final PropertyAttributes attrs)
          throws SAXException, XmlReaderException
  {
    final String dfType = attrs.getValue("type");
    final JFreeReport report = (JFreeReport)
            getRootHandler().getHelperObject(ReportDefinitionReadHandler.REPORT_KEY);
    if (dfType != null)
    {
      final Object o = ObjectUtilities.loadAndInstantiate
              (dfType, DataFactoryReadHandler.class);
      if (o instanceof DataFactory == false)
      {
        throw new SAXException("'type' did not point to a usable " +
                "DataFactory implementation.");
      }
      report.setDataFactory((DataFactory) o);
    }

    final String query = attrs.getValue("query");
    if (query != null)
    {
      report.setQuery(query);
    }
  }

  /**
   * Returns the object for this element or null, if this element does not
   * create an object.
   *
   * @return the object.
   * @throws org.jfree.xml.parser.XmlReaderException
   *          if there is a parsing error.
   */
  public Object getObject() throws XmlReaderException
  {
    return null;
  }
}
