/**
 * ========================================
 * JFreeReport : a free Java report library
 * ========================================
 *
 * Project Info:  http://www.jfree.org/jfreereport/index.html
 * Project Lead:  Thomas Morgner;
 *
 * (C) Copyright 2000-2005, by Object Refinery Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 *
 * ------------
 * RectangleReadHandler.java
 * ------------
 * (C) Copyright 2002-2005, by Object Refinery Limited.
 *
 * Original Author:  Thomas Morgner;
 * Contributor(s):   -;
 *
 * $Id: RoundRectangleReadHandler.java,v 1.1.2.1 2006/02/27 17:57:03 taqua Exp $
 *
 * Changes
 * -------
 *
 *
 */
package org.jfree.report.modules.parser.simple.readhandlers;

import java.awt.geom.RoundRectangle2D;
import java.awt.geom.Dimension2D;

import org.jfree.report.elementfactory.ElementFactory;
import org.jfree.report.elementfactory.StaticShapeElementFactory;
import org.jfree.report.modules.parser.base.PropertyAttributes;
import org.jfree.xml.ParserUtil;
import org.jfree.xml.parser.XmlReaderException;
import org.xml.sax.SAXException;

public class RoundRectangleReadHandler extends AbstractShapeElementReadHandler
{
  private static final String ARC_WIDTH_ATT = "arc-height";
  private static final String ARC_HEIGHT_ATT = "arc-width";
  private StaticShapeElementFactory elementFactory;

  public RoundRectangleReadHandler ()
  {
    elementFactory = new StaticShapeElementFactory();
  }

  /**
   * Starts parsing.
   *
   * @param atts the attributes.
   * @throws SAXException if there is a parsing error.
   */
  protected void startParsing (final PropertyAttributes atts)
          throws SAXException, XmlReaderException
  {
    super.startParsing(atts);
    if (elementFactory.getShouldDraw() == null)
    {
      elementFactory.setShouldDraw(Boolean.TRUE);
    }
    if (elementFactory.getShouldFill() == null)
    {
      elementFactory.setShouldFill(Boolean.TRUE);
    }
    elementFactory.setScale(Boolean.TRUE);
    elementFactory.setDynamicHeight(Boolean.FALSE);
    elementFactory.setKeepAspectRatio(Boolean.FALSE);
    final float arcWidth = ParserUtil.parseFloat(atts.getValue(ARC_WIDTH_ATT), 0);
    final float arcHeight = ParserUtil.parseFloat(atts.getValue(ARC_HEIGHT_ATT), 0);
    final Dimension2D size = elementFactory.getMinimumSize();
    if (size == null)
    {
      elementFactory.setShape(new RoundRectangle2D.Float(0, 0, 100, 100, arcWidth, arcHeight));
    }
    else
    {
      // this helps to keep the rounded corners in shape. This will not help
      // for elements which are defined with percentages, but at least it
      // stops some of the weird stuff.
      //
      // Later, such rounded background should be done by a suitable border definition.
      elementFactory.setShape(new RoundRectangle2D.Double
              (0, 0, Math.abs(size.getWidth()), Math.abs(size.getHeight()), arcWidth, arcHeight));
    }
  }

  protected ElementFactory getElementFactory ()
  {
    return elementFactory;
  }
}
