/**
 * ========================================
 * <libname> : a free Java <foobar> library
 * ========================================
 *
 * Project Info:  http://www.jfree.org/liblayout/
 * Project Lead:  Thomas Morgner;
 *
 * (C) Copyright 2005, by Object Refinery Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * ---------
 * ImmutableStyleSheet.java
 * ---------
 *
 * Original Author:  Thomas Morgner;
 * Contributors: -;
 *
 * $Id: ImmutableStyleSheet.java,v 1.1.2.1 2006/06/26 19:53:20 taqua Exp $
 *
 * Changes
 * -------------------------
 * 26.06.2006 : Initial version
 */
package org.jfree.report.style;

import java.io.Serializable;

/**
 * Creation-Date: 26.06.2006, 11:25:02
 *
 * @author Thomas Morgner
 */
public class ImmutableStyleSheet implements StyleSheet, Serializable
{
  private ElementStyleSheet styleSheet;

  public ImmutableStyleSheet(final ElementStyleSheet styleSheet)
  {
    if (styleSheet == null)
    {
      throw new NullPointerException();
    }
    this.styleSheet = styleSheet;
  }

  public boolean getBooleanStyleProperty(final StyleKey key)
  {
    return styleSheet.getBooleanStyleProperty(key);
  }

  public boolean getBooleanStyleProperty(final StyleKey key,
                                         final boolean defaultValue)
  {
    return styleSheet.getBooleanStyleProperty(key, defaultValue);
  }

  public FontDefinition getFontDefinitionProperty()
  {
    return styleSheet.getFontDefinitionProperty();
  }

  public int getIntStyleProperty(final StyleKey key, final int def)
  {
    return styleSheet.getIntStyleProperty(key, def);
  }

  public Object getStyleProperty(final StyleKey key)
  {
    return styleSheet.getStyleProperty(key);
  }

  public Object getStyleProperty(final StyleKey key, final Object defaultValue)
  {
    return styleSheet.getStyleProperty(key, defaultValue);
  }
}
